@@ -18,16 +18,20 @@
 
 import os
 import shutil
-import subprocess
 import tempfile
+from util import dbg_check_call
+from util import delete_tempfile
 
 
 class FatFsImage:
     def __init__(self, size_in_mb):
-        with tempfile.NamedTemporaryFile(delete=False) as f:
-            self.path = f.name
+        self.f = tempfile.NamedTemporaryFile(
+            prefix=__class__.__name__,
+            delete=delete_tempfile(),
+        )
+        self.path = self.f.name
 
-        subprocess.check_call(
+        dbg_check_call(
             [
                 'dd', 'if=/dev/zero', 'of=%s' % (self.path),
                 'count=0', 'bs=1M', 'seek=%d' % (size_in_mb), 'status=none'
@@ -35,13 +39,10 @@ class FatFsImage:
         )
         new_env = os.environ.copy()
         new_env['PATH'] = f"{os.environ['PATH']}:/sbin"
-        subprocess.check_call(['mkdosfs', '-F', '32', self.path], env=new_env)
-
-    def __del__(self):
-        os.unlink(self.path)
+        dbg_check_call(['mkdosfs', '-F', '32', self.path], env=new_env)
 
     def mkdir(self, dir):
-        subprocess.run(['mmd', '-i', self.path, dir])
+        dbg_check_call(['mmd', '-i', self.path, dir])
 
     def makedirs(self, dir):
         dirs = dir.split(os.path.sep)
@@ -50,7 +51,7 @@ class FatFsImage:
             self.mkdir(next_dir)
 
     def insert_file(self, src, dest):
-        subprocess.check_call(
+        dbg_check_call(
             [
                 'mcopy', '-i', self.path, src, '::%s' % (dest)
             ]
@@ -68,10 +69,13 @@ class EfiBootableIsoImage:
             os.makedirs(eltorito_local_root)
             shutil.copyfile(eltorito_img.path, eltorito_local_path)
 
-            with tempfile.NamedTemporaryFile(delete=False) as f:
-                self.path = f.name
+            self.f = tempfile.NamedTemporaryFile(
+                prefix=__class__.__name__,
+                delete=delete_tempfile(),
+            )
+            self.path = self.f.name
 
-            subprocess.check_call(
+            dbg_check_call(
                 [
                     'xorriso', '-as', 'mkisofs', '-J', '-l',
                     '-c', 'boot/boot.cat',
@@ -82,9 +86,6 @@ class EfiBootableIsoImage:
                 ]
             )
 
-    def __del__(self):
-        os.unlink(self.path)
-
 
 class GrubShellBootableIsoImage(EfiBootableIsoImage):
     def __init__(self, efi_arch, shim_path, grub_path):
