@@ -36,6 +36,7 @@ class QemuEfiVariant(enum.Enum):
     SECBOOT = enum.auto()
     MS_STRICTNX = enum.auto()
     SNAKEOIL = enum.auto()
+    LEGACY = enum.auto()
 
 
 class QemuEfiFlashSize(enum.Enum):
@@ -105,6 +106,9 @@ class QemuCommand:
             # We provide one size - you don't get to pick.
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
 
+        if variant == QemuEfiVariant.LEGACY:
+            return (root / 'usr/share/ovmf/OVMF.legacy.fd', None)
+
         if machine == QemuEfiMachine.AAVMF:
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
             return (
@@ -153,13 +157,20 @@ class QemuCommand:
             (code_path, vars_template_path) = self._get_default_flash_paths(
                 machine, variant, flash_size)
 
-        self.pflash = self.PflashParams(code_path, vars_template_path)
+        self.pflash = self.PflashParams(code_path, vars_template_path, variant == QemuEfiVariant.LEGACY)
         self.command = self.Machine_Base_Command[machine] + self.pflash.params
 
-    def add_disk(self, path):
-        self.command = self.command + [
-            '-drive', 'file=%s,format=raw' % (path)
-        ]
+    def add_disk(self, path, pvscsi=False):
+        if pvscsi:
+            self.command += [
+                '-device', 'pvscsi,id=scsi',
+                '-drive', f'file={path},if=none,format=raw,id=drive0',
+                '-device', 'scsi-hd,drive=drive0,bus=scsi.0'
+            ]
+        else:
+            self.command += [
+                '-drive', f'file={path},format=raw'
+            ]
 
     def add_oem_string(self, type, string):
         string = string.replace(",", ",,")
@@ -173,11 +184,18 @@ class QemuCommand:
         used as a fancy way to generate a per-instance vars file and have it
         be automatically cleaned up when the object is destroyed.
         '''
-        def __init__(self, code_path, vars_template_path):
+        def __init__(self, code_path, vars_template_path, unified=False):
+            if unified:
+                self.unified = tempfile.NamedTemporaryFile(
+                    prefix=os.path.basename(code_path),
+                    delete=delete_tempfile(),
+                )
+                with open(code_path, 'rb') as template:
+                    shutil.copyfileobj(template, self.unified)
             self.params = [
                 '-drive',
                 'file=%s,if=pflash,format=raw,unit=0,readonly=on' %
-                (code_path),
+                (self.unified.name if unified else code_path),
             ]
             if vars_template_path is None:
                 return
