@@ -23,6 +23,7 @@ from pathlib import Path
 import pexpect
 import subprocess
 import sys
+import tempfile
 import time
 import unittest
 from collections import UserDict
@@ -157,6 +158,34 @@ class BootToShellTest(unittest.TestCase):
             self.fail("%s\n" % (err))
         self.assertEqual(should_verify, verified)
 
+    def run_cmd_check_pvscsi(self, cmd, should_start=True):
+        logger.debug(f"Running: {' '.join(cmd)}")
+        child = pexpect.spawn(' '.join(cmd), encoding='UTF-8')
+        shell_started = None
+
+        if self.debug:
+            child.logfile = sys.stdout
+        try:
+            i = child.expect(['Press .* or any other key to continue.'],
+                             timeout=TEST_TIMEOUT)
+            self.assertEqual(i, 0)
+            child.sendline('\x1b')
+            i = child.expect(['Shell> '], timeout=TEST_TIMEOUT)
+            self.assertEqual(i, 0)
+            shell_started = True
+            child.sendline('drivers\r')
+            i = child.expect(['.*PVSCSI Host Driver.*PvScsiDxe'],
+                             timeout=TEST_TIMEOUT)
+            self.assertEqual(i, 0)
+            child.sendline('reset -s\r')
+        except pexpect.EOF:
+            child.close()
+            if child.exitstatus != 0:
+                self.fail("ERROR: exit code %d\n" % (child.exitstatus))
+        except pexpect.TIMEOUT as err:
+            self.fail("%s\n" % (err))
+        self.assertEqual(should_start, shell_started)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -332,6 +361,25 @@ class BootToShellTest(unittest.TestCase):
         init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    def test_ovmf_4m_legacy(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.OVMF_Q35,
+            variant=QemuEfiVariant.LEGACY,
+        )
+        init_shell_entry(q.pflash.unified.name, 'Ovmf')
+        # Create a dummy disk for PVSCSI test
+        with tempfile.NamedTemporaryFile(delete=False) as f:
+            f.write(b'\0' * 1024 * 1024)  # 1MB dummy disk
+            disk_path = f.name
+        try:
+            q.add_disk(disk_path, pvscsi=True)
+            self.run_cmd_check_pvscsi(q.command)
+        finally:
+            os.unlink(disk_path)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
